@@ -29,6 +29,12 @@ call_user_func(
             'Blog: List Categories'
         );
 
+        \TYPO3\CMS\Extbase\Utility\ExtensionUtility::registerPlugin(
+            'SG.BlogSgEnhancements',
+            'BlogHeader',
+            'Blog: Header'
+        );
+
 //        \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addStaticFile('blog_sg_enhancements', 'Configuration/TypoScript', 'Blog sg.enhancements');
 
     }
